<?php
/**
 * The actual HTML download form.
 *
 * @package manceppo
 */

namespace manceppo;

/**
 * This generates the form that provides the download.
 *
 * @param array $args Function arguments containing the post id.
 *
 * @return mixed the form as HTML.
 */
function manceppo_download_form( $args ) {
	Manceppo_Logger::log( 'DEBUG manceppo::download - preparing download form' );

	$post_id = (int) $args['id'];
	$nonce   = wp_create_nonce( 'wp_rest' );

	ob_start();

	$form_fields = new Manceppo_Form_Fields( $post_id, Manceppo_Options::is_debug_enabled() );
	$prefix      = wp_rand() . '_';
	$fields      = $form_fields->get( 'fields' );
	if ( ! is_array( $fields ) ) {
		$fields = array();
	}

	$show_recaptcha = $form_fields->get( 'show_recaptcha' );
	$show_recaptcha = ! empty( $show_recaptcha ) && 'show' === $show_recaptcha;
	if ( $show_recaptcha ) {
		wp_enqueue_script( 'manceppo_download_captcha_js', 'https://www.google.com/recaptcha/api.js?render=' . Manceppo_Options::get_recaptcha_key(), array(), '1.0.0', true );
	}

	$show_form_expanded  = 'show' === $form_fields->get( 'show_expanded' );
	$manceppo_html_utils = new Manceppo_Html_Utils( $post_id, $show_form_expanded, $prefix );
	$form_css            = 'manceppo_api_form ' . ( ! $show_form_expanded ? ' manceppo_hidden' : '' ) . ( empty( $form_fields->get( 'show_form_border' ) ) ? ' manceppo_api_form_no_border' : '' );

	$show_message_box = 'show' === $form_fields->get( 'show_message_field' );

	?>

	<div class="manceppo_download_holder">

		<?php echo $manceppo_html_utils->get_button_html(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

		<div id="<?php echo esc_attr( $prefix . 'manceppo_api_form' ); ?>"  class="<?php echo esc_attr( $form_css ); ?>" >

			<?php

			$form_intro = $form_fields->get( 'form_intro' );
			if ( empty( $form_intro ) ) {
				echo '<p>', 'In order to get the download link, please fill the form below.', '</p>';
			} else {
				echo '<p>', $manceppo_html_utils->filter_html( $form_intro ), '</p>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
			?>

			<form onsubmit="return false;">
				<input type="hidden" id="<?php echo esc_attr( $prefix . 'manceppo_campaign' ); ?>" value="<?php echo esc_attr( $form_fields->get( 'campaign' ) ); ?>">
				<input type="hidden" id="<?php echo esc_attr( $prefix . 'manceppo_download' ); ?>" value="<?php echo esc_attr( $form_fields->get( 'download' ) ); ?>">
				<input type="hidden" id="<?php echo esc_attr( $prefix . 'visitorId' ); ?>" class="manceppo_visitor_id">
				<input type="hidden" id="<?php echo esc_attr( $prefix . 'postUrl' ); ?>" value="<?php echo esc_attr( get_site_url() ); ?>">

				<?php

				$manceppo_cookie = new Manceppo_Cookie();
				$manceppo_fields = Manceppo_Fields::get_instance()->get_fields();
				foreach ( $manceppo_fields as $manceppo_field ) {
					if ( isset( $fields[ $manceppo_field->get_name() ] ) ) {
						echo $manceppo_field->to_download_form_html( $prefix, $form_fields->get( 'input_text_color' ), $manceppo_cookie, $fields ), '<br>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
				}

				echo $manceppo_html_utils->get_newsletter_html( $form_fields->get_newsletters(), $prefix ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

				if ( $show_message_box ) {
					echo '<span>Comments (optional)</span><br>';
					echo $manceppo_html_utils->get_message_field_html( $prefix ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}

				echo '<br>', $manceppo_html_utils->get_submit_button_html(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

				?>
				<input type="hidden" class="manceppo_init_form" id="<?php echo esc_attr( $prefix ); ?>" data-nonce="<?php echo esc_attr( $nonce ); ?>" data-token="<?php echo esc_attr( Manceppo_Options::get_recaptcha_key() ); ?>">
			</form>
		</div>
		<div id="<?php echo esc_attr( $prefix . 'manceppo_api_form_thankyou' ); ?>" class="manceppo_api_form_thankyou manceppo_hidden">
			<p>
				<?php echo $manceppo_html_utils->filter_html( $form_fields->get( 'thanks_body' ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			</p>
		</div>
	</div>

	<?php
	$additional_css = $form_fields->get( 'additional_css' );
	if ( '' !== $additional_css ) :
		?>
		<style type="text/css">
			<?php echo esc_html( $additional_css ); ?>
		</style>
		<?php
	endif;

	$data = ob_get_contents();

	ob_end_clean();

	return $data;
}
